# radical.entk

The documentation for Ensemble Toolkit is available at 
[http://radicalentk.readthedocs.io/en/latest/](http://radicalentk.readthedocs.io/en/latest/)


Build status: [![Build Status](https://jenkins.radical-project.org/job/radical.entk/badge/icon)](https://jenkins.radical-project.org/job/radical.entk/)

Test coverage: [![codecov](https://codecov.io/gh/radical-cybertools/radical.entk/branch/master/graph/badge.svg)](https://codecov.io/gh/radical-cybertools/radical.entk)

<!-- coverage run --source $VENV/lib/python2.7/site-packages/radical/entk -m pytest -vvv $LOC/radical.entk/tests -->
<!-- coverage html -->